jacinle.nd.shape
================

.. automodule:: jacinle.nd.shape

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      softmax
      unsqueeze
      unsqueeze_as
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: softmax

.. autofunction:: unsqueeze

.. autofunction:: unsqueeze_as


